@@ -30,13 +30,7 @@ of occupancy is so low that infiltration is enough to meet fresh air demand.
         _vintage_: Text for the vintage of the template system. This will be used
             to set efficiencies for various pieces of equipment within the system.
             The "HB Building Vintages" component has a full list of supported
-            HVAC vintages. (Default: 90.1-2013). Choose from the following.
-                * DOE Ref Pre-1980
-                * DOE Ref 1980-2004
-                * 90.1-2004
-                * 90.1-2007
-                * 90.1-2010
-                * 90.1-2013
+            HVAC vintages. (Default: ASHRAE_2013).
         _name_: Text to set the name for the heating/cooling system and to be
             incorporated into unique system identifier. If the name is not
             provided, a random name will be assigned.
@@ -47,11 +41,13 @@ of occupancy is so low that infiltration is enough to meet fresh air demand.
 
 ghenv.Component.Name = "DF HeatCool HVAC"
 ghenv.Component.NickName = 'DFHeatCoolHVAC'
-ghenv.Component.Message = '1.1.0'
+ghenv.Component.Message = '1.1.1'
 ghenv.Component.Category = 'Dragonfly'
 ghenv.Component.SubCategory = '3 :: Energy'
 ghenv.Component.AdditionalHelpFromDocStrings = '3'
 
+import os
+import json
 import uuid
 
 try:  # import the honeybee extension
@@ -62,6 +58,7 @@ except ImportError as e:
     raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))
 
 try:  # import the honeybee-energy extension
+    from honeybee_energy.config import folders
     from honeybee_energy.hvac.heatcool import EQUIPMENT_TYPES_DICT
 except ImportError as e:
     raise ImportError('\nFailed to import honeybee_energy:\n\t{}'.format(e))
@@ -84,35 +81,52 @@ except ImportError as e:
 
 # dictionary to get correct vintages
 vintages = {
-    'DOE Ref Pre-1980': 'DOE Ref Pre-1980',
-    'DOE Ref 1980-2004': 'DOE Ref 1980-2004',
-    '90.1-2004': '90.1-2004',
-    '90.1-2007': '90.1-2007',
-    '90.1-2010': '90.1-2010',
-    '90.1-2013': '90.1-2013',
-    'pre_1980': 'DOE Ref Pre-1980',
-    '1980_2004': 'DOE Ref 1980-2004',
-    '2004': '90.1-2004',
-    '2007': '90.1-2007',
-    '2010': '90.1-2010',
-    '2013': '90.1-2013',
-    None: '90.1-2013'
+    'DOE_Ref_Pre_1980': 'DOE_Ref_Pre_1980',
+    'DOE_Ref_1980_2004': 'DOE_Ref_1980_2004',
+    'ASHRAE_2004': 'ASHRAE_2004',
+    'ASHRAE_2007': 'ASHRAE_2007',
+    'ASHRAE_2010': 'ASHRAE_2010',
+    'ASHRAE_2013': 'ASHRAE_2013',
+    'DOE Ref Pre-1980': 'DOE_Ref_Pre_1980',
+    'DOE Ref 1980-2004': 'DOE_Ref_1980_2004',
+    '90.1-2004': 'ASHRAE_2004',
+    '90.1-2007': 'ASHRAE_2007',
+    '90.1-2010': 'ASHRAE_2010',
+    '90.1-2013': 'ASHRAE_2013',
+    'pre_1980': 'DOE_Ref_Pre_1980',
+    '1980_2004': 'DOE_Ref_1980_2004',
+    '2004': 'ASHRAE_2004',
+    '2007': 'ASHRAE_2007',
+    '2010': 'ASHRAE_2010',
+    '2013': 'ASHRAE_2013',
+    None: 'ASHRAE_2013'
     }
 
+# dictionary of HVAC template names
+ext_folder = folders.standards_extension_folders[0]
+hvac_reg = os.path.join(ext_folder, 'hvac_registry.json')
+with open(hvac_reg, 'r') as f:
+    hvac_dict = json.load(f)
+
+
 if all_required_inputs(ghenv.Component):
     # duplicate the initial objects
     df_objs = [obj.duplicate() for obj in _df_objs]
 
     # create the instance of the HVAC system to be applied to the rooms
     try:  # get the class for the HVAC system
-        hvac_class = EQUIPMENT_TYPES_DICT[_system_type]
+        try:
+            _sys_name = hvac_dict[_system_type]
+        except KeyError:
+            _sys_name = _system_type
+        hvac_class = EQUIPMENT_TYPES_DICT[_sys_name]
     except KeyError:
-        raise ValueError('System Type "{}" is not recognized as an all-air HVAC '
+        raise ValueError('System Type "{}" is not recognized as a HeatCool HVAC '
                          'system.'.format(_system_type))
     vintage = vintages[_vintage_]  # get the vintage of the HVAC
     # get an identifier for the HVAC system
     name = clean_and_id_ep_string(_name_) if _name_ is not None else str(uuid.uuid4())[:8]
-    hvac = hvac_class(name, vintage, _system_type)
+    hvac = hvac_class(name, vintage, _sys_name)
     if _name_ is not None:
         hvac.display_name = _name_
 
